@@ -2,144 +2,155 @@
 #'
 #' @description This function computes or extracts Bayes factors from fitted models.
 #' \cr \cr
-#' The \code{bf_*} function is an alias of the main function.
+#' The `bf_*` function is an alias of the main function.
 #'
 #' @author Mattan S. Ben-Shachar
 #'
 #' @param ... Fitted models (see details), all fit on the same data, or a single
-#'   \code{BFBayesFactor} object (see 'Details'). Ignored in \code{as.matrix()},
-#'   \code{update()}.
+#'   `BFBayesFactor` object (see 'Details'). Ignored in `as.matrix()`,
+#'   `update()`. If the following named arguments are present, they are passed
+#'   to [`insight::get_loglikelihood()`] (see details):
+#'   - `estimator` (defaults to `"ML"`)
+#'   - `check_response`  (defaults to `FALSE`)
 #' @param denominator Either an integer indicating which of the models to use as
 #'   the denominator, or a model to be used as a denominator. Ignored for
-#'   \code{BFBayesFactor}.
-#' @param object,x A \code{\link{bayesfactor_models}} object.
+#'   `BFBayesFactor`.
+#' @param object,x A [`bayesfactor_models()`] object.
 #' @param subset Vector of model indices to keep or remove.
-#' @param reference Index of model to reference to, or \code{"top"} to
-#'   reference to the best model, or \code{"bottom"} to reference to the worst
+#' @param reference Index of model to reference to, or `"top"` to
+#'   reference to the best model, or `"bottom"` to reference to the worst
 #'   model.
 #' @inheritParams hdi
 #'
-#' @note There is also a \href{https://easystats.github.io/see/articles/bayestestR.html}{\code{plot()}-method} implemented in the \href{https://easystats.github.io/see/}{\pkg{see}-package}.
+#' @note There is also a [`plot()`-method](https://easystats.github.io/see/articles/bayestestR.html)
+#' implemented in the \href{https://easystats.github.io/see/}{\pkg{see}-package}.
 #'
 #' @details
-#' If the passed models are supported by \pkg{insight} the DV of all models will be tested for equality
-#' (else this is assumed to be true), and the models' terms will be extracted (allowing for follow-up
-#' analysis with \code{bayesfactor_inclusion}).
+#' If the passed models are supported by **insight** the DV of all models will
+#' be tested for equality (else this is assumed to be true), and the models'
+#' terms will be extracted (allowing for follow-up analysis with `bayesfactor_inclusion`).
+#'
+#' - For `brmsfit` or `stanreg` models, Bayes factors are computed using the \CRANpkg{bridgesampling} package.
+#'   - `brmsfit` models must have been fitted with `save_pars = save_pars(all = TRUE)`.
+#'   - `stanreg` models must have been fitted with a defined `diagnostic_file`.
+#' - For `BFBayesFactor`, `bayesfactor_models()` is mostly a wraparound `BayesFactor::extractBF()`.
+#' - For all other model types, Bayes factors are computed using the BIC approximation.
+#'   Note that BICs are extracted from using [insight::get_loglikelihood], see documentation
+#'   there for options for dealing with transformed responses and REML estimation.
 #'
-#' \itemize{
-#'   \item For \code{brmsfit} or \code{stanreg} models, Bayes factors are computed using the \CRANpkg{bridgesampling} package.
-#'   \itemize{
-#'     \item \code{brmsfit} models must have been fitted with \code{save_pars = save_pars(all = TRUE)}.
-#'     \item \code{stanreg} models must have been fitted with a defined \code{diagnostic_file}.
-#'   }
-#'   \item For \code{BFBayesFactor}, \code{bayesfactor_models()} is mostly a wraparound \code{BayesFactor::extractBF()}.
-#'   \item BIC approximations are used to compute Bayes factors for all other model types (with a BIC method).
-#'   \itemize{
-#'     \item \strong{Note} that BICs are extracted from models as-is. So if for example you want to compare mixed-models bases on ML instead of REML, you must supply models fit with ML.
-#'   }
-#' }
 #' In order to correctly and precisely estimate Bayes factors, a rule of thumb
-#' are the 4 P's: \strong{P}roper \strong{P}riors and \strong{P}lentiful
-#' \strong{P}osteriors. How many? The number of posterior samples needed for
+#' are the 4 P's: **P**roper **P**riors and **P**lentiful
+#' **P**osteriors. How many? The number of posterior samples needed for
 #' testing is substantially larger than for estimation (the default of 4000
 #' samples may not be enough in many cases). A conservative rule of thumb is to
 #' obtain 10 times more samples than would be required for estimation
-#' (\cite{Gronau, Singmann, & Wagenmakers, 2017}). If less than 40,000 samples
-#' are detected, \code{bayesfactor_models()} gives a warning.
-#' \cr \cr
-#' See also \href{https://easystats.github.io/bayestestR/articles/bayes_factors.html}{the Bayes factors vignette}.
+#' (_Gronau, Singmann, & Wagenmakers, 2017_). If less than 40,000 samples
+#' are detected, `bayesfactor_models()` gives a warning.
+#'
+#' See also [the Bayes factors vignette](https://easystats.github.io/bayestestR/articles/bayes_factors.html).
 #'
 #' @inheritSection bayesfactor_parameters Interpreting Bayes Factors
 #'
 #' @return A data frame containing the models' formulas (reconstructed fixed and
-#'   random effects) and their \code{log(BF)}s, that prints nicely.
+#'   random effects) and their `log(BF)`s  (Use `as.numeric()` to extract the
+#'   non-log Bayes factors; see examples), that prints nicely.
 #'
-#' @examples
+#' @examplesIf require("lme4") && require("BayesFactor") && require("rstanarm") && require("brms")
 #' # With lm objects:
 #' # ----------------
-#' lm1 <- lm(Sepal.Length ~ 1, data = iris)
-#' lm2 <- lm(Sepal.Length ~ Species, data = iris)
-#' lm3 <- lm(Sepal.Length ~ Species + Petal.Length, data = iris)
-#' lm4 <- lm(Sepal.Length ~ Species * Petal.Length, data = iris)
-#' bayesfactor_models(lm1, lm2, lm3, lm4, denominator = 1)
-#' bayesfactor_models(lm2, lm3, lm4, denominator = lm1) # same result
-#' BFM <- bayesfactor_models(lm1, lm2, lm3, lm4, denominator = lm1) # same result
+#' lm1 <- lm(mpg ~ 1, data = mtcars)
+#' lm2 <- lm(mpg ~ hp, data = mtcars)
+#' lm3 <- lm(mpg ~ hp + drat, data = mtcars)
+#' lm4 <- lm(mpg ~ hp * drat, data = mtcars)
+#' (BFM <- bayesfactor_models(lm1, lm2, lm3, lm4, denominator = 1))
+#' # bayesfactor_models(lm2, lm3, lm4, denominator = lm1) # same result
+#' # bayesfactor_models(lm1, lm2, lm3, lm4, denominator = lm1) # same result
 #'
 #' update(BFM, reference = "bottom")
 #' as.matrix(BFM)
-#' \dontrun{
+#' as.numeric(BFM)
+#'
+#' lm2b <- lm(sqrt(mpg) ~ hp, data = mtcars)
+#' # Set check_response = TRUE for transformed responses
+#' bayesfactor_models(lm2b, denominator = lm2, check_response = TRUE)
+#'
+#' \donttest{
 #' # With lmerMod objects:
 #' # ---------------------
-#' if (require("lme4")) {
-#'   lmer1 <- lmer(Sepal.Length ~ Petal.Length + (1 | Species), data = iris)
-#'   lmer2 <- lmer(Sepal.Length ~ Petal.Length + (Petal.Length | Species), data = iris)
-#'   lmer3 <- lmer(
-#'     Sepal.Length ~ Petal.Length + (Petal.Length | Species) + (1 | Petal.Width),
-#'     data = iris
-#'   )
-#'   bayesfactor_models(lmer1, lmer2, lmer3, denominator = 1)
-#'   bayesfactor_models(lmer1, lmer2, lmer3, denominator = lmer1)
-#' }
+#' lmer1 <- lme4::lmer(Sepal.Length ~ Petal.Length + (1 | Species), data = iris)
+#' lmer2 <- lme4::lmer(Sepal.Length ~ Petal.Length + (Petal.Length | Species), data = iris)
+#' lmer3 <- lme4::lmer(
+#'   Sepal.Length ~ Petal.Length + (Petal.Length | Species) + (1 | Petal.Width),
+#'   data = iris
+#' )
+#' bayesfactor_models(lmer1, lmer2, lmer3,
+#'   denominator = 1,
+#'   estimator = "REML"
+#' )
 #'
 #' # rstanarm models
 #' # ---------------------
 #' # (note that a unique diagnostic_file MUST be specified in order to work)
-#' if (require("rstanarm")) {
-#'   stan_m0 <- stan_glm(Sepal.Length ~ 1,
-#'     data = iris,
-#'     family = gaussian(),
-#'     diagnostic_file = file.path(tempdir(), "df0.csv")
-#'   )
-#'   stan_m1 <- stan_glm(Sepal.Length ~ Species,
-#'     data = iris,
-#'     family = gaussian(),
-#'     diagnostic_file = file.path(tempdir(), "df1.csv")
-#'   )
-#'   stan_m2 <- stan_glm(Sepal.Length ~ Species + Petal.Length,
-#'     data = iris,
-#'     family = gaussian(),
-#'     diagnostic_file = file.path(tempdir(), "df2.csv")
-#'   )
-#'   bayesfactor_models(stan_m1, stan_m2, denominator = stan_m0)
-#' }
+#' stan_m0 <- suppressWarnings(rstanarm::stan_glm(Sepal.Length ~ 1,
+#'   data = iris,
+#'   family = gaussian(),
+#'   diagnostic_file = file.path(tempdir(), "df0.csv")
+#' ))
+#' stan_m1 <- suppressWarnings(rstanarm::stan_glm(Sepal.Length ~ Species,
+#'   data = iris,
+#'   family = gaussian(),
+#'   diagnostic_file = file.path(tempdir(), "df1.csv")
+#' ))
+#' stan_m2 <- suppressWarnings(rstanarm::stan_glm(Sepal.Length ~ Species + Petal.Length,
+#'   data = iris,
+#'   family = gaussian(),
+#'   diagnostic_file = file.path(tempdir(), "df2.csv")
+#' ))
+#' bayesfactor_models(stan_m1, stan_m2, denominator = stan_m0, verbose = FALSE)
 #'
 #'
 #' # brms models
 #' # --------------------
 #' # (note the save_pars MUST be set to save_pars(all = TRUE) in order to work)
-#' if (require("brms")) {
-#'   brm1 <- brm(Sepal.Length ~ 1, data = iris, save_all_pars = TRUE)
-#'   brm2 <- brm(Sepal.Length ~ Species, data = iris, save_all_pars = TRUE)
-#'   brm3 <- brm(
-#'     Sepal.Length ~ Species + Petal.Length,
-#'     data = iris,
-#'     save_pars = save_pars(all = TRUE)
-#'   )
+#' brm1 <- brms::brm(Sepal.Length ~ 1, data = iris, save_pars = save_pars(all = TRUE))
+#' brm2 <- brms::brm(Sepal.Length ~ Species, data = iris, save_pars = save_pars(all = TRUE))
+#' brm3 <- brms::brm(
+#'   Sepal.Length ~ Species + Petal.Length,
+#'   data = iris,
+#'   save_pars = save_pars(all = TRUE)
+#' )
 #'
-#'   bayesfactor_models(brm1, brm2, brm3, denominator = 1)
-#' }
+#' bayesfactor_models(brm1, brm2, brm3, denominator = 1, verbose = FALSE)
 #'
 #'
 #' # BayesFactor
 #' # ---------------------------
-#' if (require("BayesFactor")) {
-#'   data(puzzles)
-#'   BF <- anovaBF(RT ~ shape * color + ID,
-#'     data = puzzles,
-#'     whichRandom = "ID", progress = FALSE
-#'   )
-#'   BF
-#'   bayesfactor_models(BF) # basically the same
-#' }
+#' data(puzzles)
+#' BF <- BayesFactor::anovaBF(RT ~ shape * color + ID,
+#'   data = puzzles,
+#'   whichRandom = "ID", progress = FALSE
+#' )
+#' BF
+#' bayesfactor_models(BF) # basically the same
 #' }
+#'
 #' @references
-#' \itemize{
-#'   \item Gronau, Q. F., Singmann, H., & Wagenmakers, E. J. (2017). Bridgesampling: An R package for estimating normalizing constants. arXiv preprint arXiv:1710.08162.
-#'   \item Kass, R. E., and Raftery, A. E. (1995). Bayes Factors. Journal of the American Statistical Association, 90(430), 773-795.
-#'   \item Robert, C. P. (2016). The expected demise of the Bayes factor. Journal of Mathematical Psychology, 72, 33–37.
-#'   \item Wagenmakers, E. J. (2007). A practical solution to the pervasive problems of p values. Psychonomic bulletin & review, 14(5), 779-804.
-#'   \item Wetzels, R., Matzke, D., Lee, M. D., Rouder, J. N., Iverson, G. J., and Wagenmakers, E.-J. (2011). Statistical Evidence in Experimental Psychology: An Empirical Comparison Using 855 t Tests. Perspectives on Psychological Science, 6(3), 291–298. \doi{10.1177/1745691611406923}
-#' }
+#' - Gronau, Q. F., Singmann, H., & Wagenmakers, E. J. (2017). Bridgesampling: An R package for estimating
+#'   normalizing constants. arXiv preprint arXiv:1710.08162.
+#'
+#' - Kass, R. E., and Raftery, A. E. (1995). Bayes Factors. Journal of the American Statistical Association,
+#'   90(430), 773-795.
+#'
+#' - Robert, C. P. (2016). The expected demise of the Bayes factor. Journal of Mathematical Psychology,
+#'   72, 33–37.
+#'
+#' - Wagenmakers, E. J. (2007). A practical solution to the pervasive problems of p values.
+#'   Psychonomic bulletin & review, 14(5), 779-804.
+#'
+#' - Wetzels, R., Matzke, D., Lee, M. D., Rouder, J. N., Iverson, G. J., and Wagenmakers, E.-J. (2011).
+#'   Statistical Evidence in Experimental Psychology: An Empirical Comparison Using 855 t Tests.
+#'   Perspectives on Psychological Science, 6(3), 291–298. \doi{10.1177/1745691611406923}
+#'
 #' @export
 bayesfactor_models <- function(..., denominator = 1, verbose = TRUE) {
   UseMethod("bayesfactor_models")
@@ -149,15 +160,25 @@ bayesfactor_models <- function(..., denominator = 1, verbose = TRUE) {
 #' @export
 bf_models <- bayesfactor_models
 
+
 #' @export
+#' @rdname bayesfactor_models
 bayesfactor_models.default <- function(..., denominator = 1, verbose = TRUE) {
   # Organize the models and their names
   mods <- list(...)
   denominator <- list(denominator)
-
   cl <- match.call(expand.dots = FALSE)
-  names(mods) <- sapply(cl$`...`, .safe_deparse)
-  names(denominator) <- .safe_deparse(cl$denominator)
+
+  estimator <- mods[["estimator"]]
+  check_response <- mods[["check_response"]]
+  if (is.null(estimator)) estimator <- "ML"
+  if (is.null(check_response)) check_response <- FALSE
+  mods[["check_response"]] <- mods[["estimator"]] <- NULL
+  cl$...$estimator <- cl$...$check_response <- NULL
+
+
+  names(mods) <- sapply(cl$`...`, insight::safe_deparse)
+  names(denominator) <- insight::safe_deparse(cl$denominator)
 
   mods <- .cleanup_BF_models(mods, denominator, cl)
   mforms <- names(mods)
@@ -165,7 +186,7 @@ bayesfactor_models.default <- function(..., denominator = 1, verbose = TRUE) {
 
   # Get formula / model names
   # supported models
-  supported_models <- sapply(mods, insight::is_model_supported)
+  supported_models <- vapply(mods, insight::is_model_supported, TRUE)
   if (all(supported_models)) {
     temp_forms <- sapply(mods, .find_full_formula)
 
@@ -175,8 +196,43 @@ bayesfactor_models.default <- function(..., denominator = 1, verbose = TRUE) {
     supported_models[!has_terms] <- FALSE
   }
 
+  objects <- .safe(do.call(insight::ellipsis_info, c(mods, verbose = FALSE)))
+  if (!is.null(objects)) {
+    were_checked <- inherits(objects, "ListModels")
+
+    # Validate response
+    if (were_checked && verbose && !isTRUE(attr(objects, "same_response"))) {
+      insight::format_warning(
+        "When comparing models, please note that probably not all models were fit from same data."
+      )
+    }
+
+    # Get BIC
+    if (were_checked && estimator == "REML" &&
+      any(vapply(mods, insight::is_mixed_model, TRUE)) &&
+      !isTRUE(attr(objects, "same_fixef")) &&
+      verbose) {
+      insight::format_warning(paste(
+        "Information criteria (like BIC) based on REML fits (i.e. `estimator=\"REML\"`)",
+        "are not recommended for comparison between models with different fixed effects.",
+        "Concider setting `estimator=\"ML\"`."
+      ))
+    }
+  } else if (verbose) {
+    insight::format_alert("Unable to validate that all models were fit with the same data.")
+  }
+
+  mBIC <- tryCatch(sapply(mods, function(m) {
+    LL <- insight::get_loglikelihood(
+      m,
+      estimator = estimator, check_response = check_response
+    )
+    stats::BIC(LL)
+  }), error = function(...) NULL)
+
+  if (is.null(mBIC)) mBIC <- sapply(mods, stats::BIC)
+
   # Get BF
-  mBIC <- .BIC_list(mods)
   mBFs <- bic_to_bf(mBIC, denominator = mBIC[denominator], log = TRUE)
 
   res <- data.frame(
@@ -195,18 +251,16 @@ bayesfactor_models.default <- function(..., denominator = 1, verbose = TRUE) {
 
 
 .bayesfactor_models_stan <- function(mods, denominator = 1, verbose = TRUE) {
-
   # Warn
   n_samps <- sapply(mods, function(x) {
     alg <- insight::find_algorithm(x)
     if (is.null(alg$iterations)) alg$iterations <- alg$sample
     (alg$iterations - alg$warmup) * alg$chains
   })
-  if (any(n_samps < 4e4)) {
-    warning(
-      "Bayes factors might not be precise.\n",
-      "For precise Bayes factors, it is recommended sampling at least 40,000 posterior samples.",
-      call. = FALSE, immediate. = TRUE
+  if (any(n_samps < 4e4) && verbose) {
+    insight::format_warning(
+      "Bayes factors might not be precise.",
+      "For precise Bayes factors, sampling at least 40,000 posterior samples is recommended."
     )
   }
 
@@ -227,6 +281,7 @@ bayesfactor_models.default <- function(..., denominator = 1, verbose = TRUE) {
   )
 }
 
+
 #' @keywords internal
 .bayesfactor_models_stan_REG <- function(mods, denominator, verbose = TRUE) {
   insight::check_if_installed("bridgesampling")
@@ -239,17 +294,10 @@ bayesfactor_models.default <- function(..., denominator = 1, verbose = TRUE) {
   )
 
   if (!all(from_same_data_as_den)) {
-    stop("Models were not computed from the same data.")
+    insight::format_error("Models were not computed from the same data.")
   }
 
-  # Get BF
-  if (verbose) {
-    message("Computation of Bayes factors: estimating marginal likelihood, please wait...")
-  }
-
-  mML <- lapply(mods, function(x) {
-    bridgesampling::bridge_sampler(x, silent = TRUE)
-  })
+  mML <- lapply(mods, .get_marglik, verbose = verbose)
 
   mBFs <- sapply(mML, function(x) {
     bf <- bridgesampling::bf(x, mML[[denominator]], log = TRUE)
@@ -268,11 +316,11 @@ bayesfactor_models.default <- function(..., denominator = 1, verbose = TRUE) {
 
 .bayesfactor_models_stan_SEM <- function(mods, denominator, verbose = TRUE) {
   utils::capture.output(
-    suppressWarnings(
+    suppressWarnings({
       mBFs <- sapply(mods, function(m) {
         blavaan::blavCompare(m, mods[[denominator]])[["bf"]][1]
       })
-    )
+    })
   )
 
   res <- data.frame(
@@ -285,33 +333,21 @@ bayesfactor_models.default <- function(..., denominator = 1, verbose = TRUE) {
 
 #' @export
 bayesfactor_models.stanreg <- function(..., denominator = 1, verbose = TRUE) {
-  insight::check_if_installed("rstanarm")
+  mods <- list(...)
+  if (inherits(mods[[1]], "stanreg")) {
+    insight::check_if_installed("rstanarm")
+  } else if (inherits(mods[[1]], "brmsfit")) {
+    insight::check_if_installed("brms")
+  } else if (inherits(mods[[1]], "blavaan")) {
+    insight::check_if_installed("blavaan")
+  }
 
   # Organize the models and their names
-  mods <- list(...)
   denominator <- list(denominator)
 
   cl <- match.call(expand.dots = FALSE)
-  names(mods) <- sapply(cl$`...`, .safe_deparse)
-  names(denominator) <- .safe_deparse(cl$denominator)
-
-  mods <- .cleanup_BF_models(mods, denominator, cl)
-  denominator <- attr(mods, "denominator", exact = TRUE)
-
-  .bayesfactor_models_stan(mods, denominator = denominator, verbose = verbose)
-}
-
-#' @export
-bayesfactor_models.brmsfit <- function(..., denominator = 1, verbose = TRUE) {
-  insight::check_if_installed("brms")
-
-  # Organize the models and their names
-  mods <- list(...)
-  denominator <- list(denominator)
-
-  cl <- match.call(expand.dots = FALSE)
-  names(mods) <- sapply(cl$`...`, .safe_deparse)
-  names(denominator) <- .safe_deparse(cl$denominator)
+  names(mods) <- sapply(cl$`...`, insight::safe_deparse)
+  names(denominator) <- insight::safe_deparse(cl$denominator)
 
   mods <- .cleanup_BF_models(mods, denominator, cl)
   denominator <- attr(mods, "denominator", exact = TRUE)
@@ -321,22 +357,12 @@ bayesfactor_models.brmsfit <- function(..., denominator = 1, verbose = TRUE) {
 
 
 #' @export
-bayesfactor_models.blavaan <- function(..., denominator = 1, verbose = TRUE) {
-  insight::check_if_installed("blavaan")
+bayesfactor_models.brmsfit <- bayesfactor_models.stanreg
 
-  # Organize the models and their names
-  mods <- list(...)
-  denominator <- list(denominator)
 
-  cl <- match.call(expand.dots = FALSE)
-  names(mods) <- sapply(cl$`...`, .safe_deparse)
-  names(denominator) <- .safe_deparse(cl$denominator)
+#' @export
+bayesfactor_models.blavaan <- bayesfactor_models.stanreg
 
-  mods <- .cleanup_BF_models(mods, denominator, cl)
-  denominator <- attr(mods, "denominator", exact = TRUE)
-
-  .bayesfactor_models_stan(mods, denominator = denominator, verbose = verbose)
-}
 
 #' @export
 bayesfactor_models.BFBayesFactor <- function(..., verbose = TRUE) {
@@ -347,7 +373,7 @@ bayesfactor_models.BFBayesFactor <- function(..., verbose = TRUE) {
   mBFs <- c(0, BayesFactor::extractBF(models, TRUE, TRUE))
   mforms <- sapply(c(models@denominator, models@numerator), function(x) x@shortName)
 
-  if (!"BFlinearModel" %in% class(models@denominator)) {
+  if (!inherits(models@denominator, "BFlinearModel")) {
     mforms <- .clean_non_linBF_mods(mforms)
   } else {
     mforms[mforms == "Intercept only"] <- "1"
@@ -362,7 +388,7 @@ bayesfactor_models.BFBayesFactor <- function(..., verbose = TRUE) {
   .bf_models_output(res,
     denominator = 1,
     bf_method = "JZS (BayesFactor)",
-    unsupported_models = !"BFlinearModel" %in% class(models@denominator)
+    unsupported_models = !inherits(models@denominator, "BFlinearModel")
   )
 }
 
@@ -422,7 +448,7 @@ as.matrix.bayesfactor_models <- function(x, ...) {
     mods <- mods[[1]]
     mod_names <- tryCatch(
       {
-        sapply(cl$`...`[[1]][-1], .safe_deparse)
+        sapply(cl$`...`[[1]][-1], insight::safe_deparse)
       },
       error = function(e) {
         NULL
@@ -452,7 +478,11 @@ as.matrix.bayesfactor_models <- function(x, ...) {
 
 
 #' @keywords internal
-.bf_models_output <- function(res, denominator = 1, bf_method = "method", unsupported_models = FALSE, model_names = NULL) {
+.bf_models_output <- function(res,
+                              denominator = 1,
+                              bf_method = "method",
+                              unsupported_models = FALSE,
+                              model_names = NULL) {
   attr(res, "denominator") <- denominator
   attr(res, "BF_method") <- bf_method
   attr(res, "unsupported_models") <- unsupported_models
@@ -483,21 +513,6 @@ as.matrix.bayesfactor_models <- function(x, ...) {
   paste(c(conditional, random), collapse = " + ")
 }
 
-#' @keywords internal
-.BIC_list <- function(x) {
-  sapply(x, function(m) {
-    tryCatch(
-      {
-        bic <- stats::BIC(m, x[[1]])
-        bic$BIC[1]
-      },
-      warning = function(w) {
-        stop(conditionMessage(w), call. = FALSE)
-      }
-    )
-  })
-}
-
 #' @keywords internal
 .clean_non_linBF_mods <- function(m_names) {
   tryCatch(
@@ -505,12 +520,12 @@ as.matrix.bayesfactor_models <- function(x, ...) {
       m_txt <- character(length = length(m_names))
 
       ## Detect types ##
-      is_null <- grepl("^Null", m_names)
-      is_rho <- grepl("rho", m_names)
-      is_mu <- grepl("mu", m_names)
-      is_d <- grepl("d", m_names)
-      is_p <- grepl("p", m_names)
-      is_range <- grepl("<", m_names)
+      is_null <- startsWith(m_names, "Null")
+      is_rho <- grepl("rho", m_names, fixed = TRUE)
+      is_mu <- grepl("mu", m_names, fixed = TRUE)
+      is_d <- grepl("d", m_names, fixed = TRUE)
+      is_p <- grepl("p", m_names, fixed = TRUE)
+      is_range <- grepl("<", m_names, fixed = TRUE)
 
       ## Range Alts ##
       m_txt[!is_null & is_range] <-
@@ -518,35 +533,35 @@ as.matrix.bayesfactor_models <- function(x, ...) {
 
       ## Null models + Not nulls ##
       if (any(is_d & is_p)) {
-        is_null <- !grepl("^Non", m_names)
+        is_null <- !startsWith(m_names, "Non")
         temp <- m_names[is_null][1]
         mi <- gregexpr("\\(.*\\)", temp)
-        aa <- unlist(regmatches(temp, m = mi))
+        aa <- unlist(regmatches(temp, m = mi), use.names = FALSE)
 
-        m_txt[is_null] <- sub("a=", "a = ", aa)
-        m_txt[!is_null & !is_range] <- sub("a=", "a != ", aa)
+        m_txt[is_null] <- sub("a=", "a = ", aa, fixed = TRUE)
+        m_txt[!is_null & !is_range] <- sub("a=", "a != ", aa, fixed = TRUE)
       } else if (any(is_rho)) {
         m_txt[is_null] <- "rho = 0"
         m_txt[!is_null & !is_range] <- "rho != 0"
-        m_txt <- sub("<rho<", " < rho < ", m_txt)
+        m_txt <- sub("<rho<", " < rho < ", m_txt, fixed = TRUE)
       } else if (any(is_d | is_mu)) {
         m_txt[is_null] <- "d = 0"
         m_txt[!is_null & !is_range] <- "d != 0"
-        m_txt <- sub("<d<", " < d < ", m_txt)
+        m_txt <- sub("<d<", " < d < ", m_txt, fixed = TRUE)
       } else if (any(is_p)) {
         temp <- m_names[is_null][1]
         mi <- gregexpr("[0-9|\\.]+", temp)
-        pp <- unlist(regmatches(temp, m = mi))
+        pp <- unlist(regmatches(temp, m = mi), use.names = FALSE)
 
         m_txt[is_null] <- paste0("p = ", pp)
         m_txt[!is_null & !is_range] <- paste0("p != ", pp)
-        m_txt <- sub("<p<", " < p < ", m_txt)
+        m_txt <- sub("<p<", " < p < ", m_txt, fixed = TRUE)
       } else {
-        stop("!")
+        stop("!", call. = FALSE)
       }
 
       ## wrap with () for readability ##
-      is_wrapped <- grepl("\\(", m_txt)
+      is_wrapped <- grepl("(", m_txt, fixed = TRUE)
       m_txt[!is_wrapped] <- paste0("(", m_txt[!is_wrapped], ")")
 
       return(m_txt)
@@ -556,3 +571,18 @@ as.matrix.bayesfactor_models <- function(x, ...) {
     }
   )
 }
+
+#' @keywords internal
+.get_marglik <- function(mod, verbose, ...) {
+  # Add a check here for brmsfit object to avoid unnecessary computation of the ML
+  if (inherits(mod, "brmsfit") && "marglik" %in% names(mod$criteria)) {
+    return(stats::median(mod$criteria$marglik$logml))
+  }
+
+  # Else... Get marginal likelihood
+  if (verbose) {
+    insight::format_alert("Computation of Marginal Likelihood: estimating marginal likelihood, please wait...")
+  }
+  # Should probably allow additional arguments such as reps or cores to for bridge_sampler
+  bridgesampling::bridge_sampler(mod, silent = TRUE)
+}
