@@ -1,25 +1,27 @@
 #' Check if Prior is Informative
 #'
-#' Performs a simple test to check whether the prior is informative to the posterior. This idea, and the accompanying heuristics, were discussed in \href{https://statmodeling.stat.columbia.edu/2019/08/10/}{this blogpost}.
+#' Performs a simple test to check whether the prior is informative to the
+#' posterior. This idea, and the accompanying heuristics, were discussed in
+#' [this blogpost](https://statmodeling.stat.columbia.edu/2019/08/10/).
 #'
-#' @param method Can be \code{"gelman"} or \code{"lakeland"}. For the
-#'   \code{"gelman"} method, if the SD of the posterior is more than 0.1 times
+#' @param method Can be `"gelman"` or `"lakeland"`. For the
+#'   `"gelman"` method, if the SD of the posterior is more than 0.1 times
 #'   the SD of the prior, then the prior is considered as informative. For the
-#'   \code{"lakeland"} method, the prior is considered as informative if the
-#'   posterior falls within the 95\% HDI of the prior.
+#'   `"lakeland"` method, the prior is considered as informative if the
+#'   posterior falls within the `95%` HDI of the prior.
 #' @param simulate_priors Should prior distributions be simulated using
-#'   \code{\link{simulate_prior}} (default; faster) or sampled via
-#'   \code{\link{unupdate}} (slower, more accurate).
+#'   [simulate_prior()] (default; faster) or sampled via
+#'   [unupdate()] (slower, more accurate).
 #' @inheritParams effective_sample
 #' @inheritParams hdi
 #'
 #' @return A data frame with two columns: The parameter names and the quality
-#'   of the prior (which might be \code{"informative"}, \code{"uninformative"})
-#'   or \code{"not determinable"} if the prior distribution could not be
+#'   of the prior (which might be `"informative"`, `"uninformative"`)
+#'   or `"not determinable"` if the prior distribution could not be
 #'   determined).
 #'
 #' @examples
-#' \dontrun{
+#' \donttest{
 #' library(bayestestR)
 #' if (require("rstanarm")) {
 #'   model <- stan_glm(mpg ~ wt + am, data = mtcars, chains = 1, refresh = 0)
@@ -35,7 +37,8 @@
 #'   )
 #'   check_prior(model, method = "gelman")
 #'   check_prior(model, method = "lakeland")
-#'   plot(si(model)) # can provide visual confirmation to the Lakeland method
+#'   # can provide visual confirmation to the Lakeland method
+#'   plot(si(model, verbose = FALSE))
 #' }
 #' }
 #' @references https://statmodeling.stat.columbia.edu/2019/08/10/
@@ -57,7 +60,6 @@ check_prior.brmsfit <- function(model,
                                 parameters = NULL,
                                 verbose = TRUE,
                                 ...) {
-
   # check arguments
   effects <- match.arg(effects)
   component <- match.arg(component)
@@ -101,13 +103,15 @@ check_prior.blavaan <- check_prior.brmsfit
 
 
 #' @keywords internal
-.check_prior <- function(priors, posteriors, method = "gelman", verbose = TRUE, cleaned_parameters = NULL) {
-
-  # sanity check for matching parameters. Some weird priors like
+.check_prior <- function(priors,
+                         posteriors,
+                         method = "gelman",
+                         verbose = TRUE,
+                         cleaned_parameters = NULL) {
+  # validation check for matching parameters. Some weird priors like
   # rstanarm's R2 prior might cause problems
 
   if (!is.null(cleaned_parameters) && ncol(priors) != ncol(posteriors)) {
-
     ## TODO for now only fixed effects
     if ("Effects" %in% colnames(cleaned_parameters)) {
       cleaned_parameters <- cleaned_parameters[cleaned_parameters$Effects == "fixed", ]
@@ -143,19 +147,19 @@ check_prior.blavaan <- check_prior.brmsfit
     priors <- priors[common_columns]
     posteriors <- posteriors[common_columns]
     if (verbose) {
-      warning("Parameters and priors could not be fully matched. Only returning results for parameters with matching priors.", call. = FALSE)
+      insight::format_warning(
+        "Parameters and priors could not be fully matched. Only returning results for parameters with matching priors."
+      )
     }
   }
 
 
   # for priors whose distribution cannot be simulated, prior values are
   # all NA. Catch those, and warn user
-  all_missing <- sapply(priors, function(i) {
-    all(is.na(i))
-  })
+  all_missing <- vapply(priors, function(i) all(is.na(i)), TRUE)
 
   if (any(all_missing) && verbose) {
-    warning("Some priors could not be simulated.", call. = FALSE)
+    insight::format_warning("Some priors could not be simulated.")
   }
 
   .gelman <- function(prior, posterior) {
@@ -172,7 +176,7 @@ check_prior.blavaan <- check_prior.brmsfit
     if (all(is.na(prior))) {
       "not determinable"
     } else {
-      hdi <- hdi(prior, ci = .95)
+      hdi <- hdi(prior, ci = 0.95)
       r <- rope(posterior, ci = 1, range = c(hdi$CI_low, hdi$CI_high))
       if (as.numeric(r) > 0.99) {
         "informative"
@@ -187,7 +191,7 @@ check_prior.blavaan <- check_prior.brmsfit
   } else if (method == "lakeland") {
     result <- mapply(.lakeland, priors, posteriors)
   } else {
-    stop("method should be 'gelman' or 'lakeland'.")
+    insight::format_error("method should be 'gelman' or 'lakeland'.")
   }
 
   data.frame(
