@@ -1,30 +1,30 @@
 #' @title Summary of Bayesian multivariate-response mediation-models
 #' @name mediation
 #'
-#' @description \code{mediation()} is a short summary for multivariate-response
+#' @description `mediation()` is a short summary for multivariate-response
 #'   mediation-models, i.e. this function computes average direct and average
 #'   causal mediation effects of multivariate response models.
 #'
-#' @param model A \code{brmsfit} or \code{stanmvreg} object.
+#' @param model A `brmsfit` or `stanmvreg` object.
 #' @param treatment Character, name of the treatment variable (or direct effect)
-#'   in a (multivariate response) mediator-model. If missing, \code{mediation()}
+#'   in a (multivariate response) mediator-model. If missing, `mediation()`
 #'   tries to find the treatment variable automatically, however, this may fail.
 #' @param mediator Character, name of the mediator variable in a (multivariate
-#'   response) mediator-model. If missing, \code{mediation()} tries to find the
+#'   response) mediator-model. If missing, `mediation()` tries to find the
 #'   treatment variable automatically, however, this may fail.
 #' @param response A named character vector, indicating the names of the response
-#'   variables to be used for the mediation analysis. Usually can be \code{NULL},
-#'   in which case these variables are retrieved automatically. If not \code{NULL},
+#'   variables to be used for the mediation analysis. Usually can be `NULL`,
+#'   in which case these variables are retrieved automatically. If not `NULL`,
 #'   names should match the names of the model formulas,
-#'   \code{names(insight::find_response(model, combine = TRUE))}. This can be
+#'   `names(insight::find_response(model, combine = TRUE))`. This can be
 #'   useful if, for instance, the mediator variable used as predictor has a different
 #'   name from the mediator variable used as response. This might occur when the
 #'   mediator is transformed in one model, but used "as is" as response variable
-#'   in the other model. Example: The mediator \code{m} is used as response variable,
-#'   but the centered version \code{m_center} is used as mediator variable. The
+#'   in the other model. Example: The mediator `m` is used as response variable,
+#'   but the centered version `m_center` is used as mediator variable. The
 #'   second response variable (for the treatment model, with the mediator as
-#'   additional predictor), \code{y}, is not transformed. Then we could use
-#'   \code{response} like this: \code{mediation(model, response = c(m = "m_center", y = "y"))}.
+#'   additional predictor), `y`, is not transformed. Then we could use
+#'   `response` like this: `mediation(model, response = c(m = "m_center", y = "y"))`.
 #' @param ... Not used.
 #' @inheritParams ci
 #' @inheritParams describe_posterior
@@ -32,32 +32,32 @@
 #' @return A data frame with direct, indirect, mediator and
 #'   total effect of a multivariate-response mediation-model, as well as the
 #'   proportion mediated. The effect sizes are median values of the posterior
-#'   samples (use \code{centrality} for other centrality indices).
+#'   samples (use `centrality` for other centrality indices).
 #'
-#' @details \code{mediation()} returns a data frame with information on the
-#'       \emph{direct effect} (mean value of posterior samples from \code{treatment}
-#'       of the outcome model), \emph{mediator effect} (mean value of posterior
-#'       samples from \code{mediator} of the outcome model), \emph{indirect effect}
-#'       (mean value of the multiplication of the posterior samples from
-#'       \code{mediator} of the outcome model and the posterior samples from
-#'       \code{treatment} of the mediation model) and the total effect (mean
-#'       value of sums of posterior samples used for the direct and indirect
-#'       effect). The \emph{proportion mediated} is the indirect effect divided
-#'       by the total effect.
-#'       \cr \cr
-#'       For all values, the 89\% credible intervals are calculated by default.
-#'       Use \code{ci} to calculate a different interval.
-#'       \cr \cr
-#'       The arguments \code{treatment} and \code{mediator} do not necessarily
-#'       need to be specified. If missing, \code{mediation()} tries to find the
-#'       treatment and mediator variable automatically. If this does not work,
-#'       specify these variables.
-#'       \cr \cr
-#'       The direct effect is also called \emph{average direct effect} (ADE),
-#'       the indirect effect is also called \emph{average causal mediation effects}
-#'       (ACME). See also \cite{Tingley et al. 2014} and \cite{Imai et al. 2010}.
+#' @details `mediation()` returns a data frame with information on the
+#'  *direct effect* (mean value of posterior samples from `treatment`
+#'  of the outcome model), *mediator effect* (mean value of posterior
+#'  samples from `mediator` of the outcome model), *indirect effect*
+#'  (mean value of the multiplication of the posterior samples from
+#'  `mediator` of the outcome model and the posterior samples from
+#'  `treatment` of the mediation model) and the total effect (mean
+#'  value of sums of posterior samples used for the direct and indirect
+#'  effect). The *proportion mediated* is the indirect effect divided
+#'  by the total effect.
 #'
-#' @note There is an \code{as.data.frame()} method that returns the posterior
+#'  For all values, the `89%` credible intervals are calculated by default.
+#'  Use `ci` to calculate a different interval.
+#'
+#'  The arguments `treatment` and `mediator` do not necessarily
+#'  need to be specified. If missing, `mediation()` tries to find the
+#'  treatment and mediator variable automatically. If this does not work,
+#'  specify these variables.
+#'
+#'  The direct effect is also called *average direct effect* (ADE),
+#'  the indirect effect is also called *average causal mediation effects*
+#'  (ACME). See also _Tingley et al. 2014_ and _Imai et al. 2010_.
+#'
+#' @note There is an `as.data.frame()` method that returns the posterior
 #'   samples of the effects, which can be used for further processing in the
 #'   different \pkg{bayestestR} package.
 #'
@@ -75,8 +75,8 @@
 #' @seealso The \pkg{mediation} package for a causal mediation analysis in
 #'   the frequentist framework.
 #'
-#' @examples
-#' \dontrun{
+#' @examplesIf require("mediation") && require("brms") && require("rstanarm")
+#' \donttest{
 #' library(mediation)
 #' library(brms)
 #' library(rstanarm)
@@ -94,22 +94,21 @@
 #' # Fit Bayesian mediation model in brms
 #' f1 <- bf(job_seek ~ treat + econ_hard + sex + age)
 #' f2 <- bf(depress2 ~ treat + job_seek + econ_hard + sex + age)
-#' m2 <- brm(f1 + f2 + set_rescor(FALSE), data = jobs, cores = 4, refresh = 0)
+#' m2 <- brm(f1 + f2 + set_rescor(FALSE), data = jobs, refresh = 0)
 #'
 #' # Fit Bayesian mediation model in rstanarm
-#' m3 <- stan_mvmer(
+#' m3 <- suppressWarnings(stan_mvmer(
 #'   list(
 #'     job_seek ~ treat + econ_hard + sex + age + (1 | occp),
 #'     depress2 ~ treat + job_seek + econ_hard + sex + age + (1 | occp)
 #'   ),
 #'   data = jobs,
-#'   cores = 4,
 #'   refresh = 0
-#' )
+#' ))
 #'
 #' summary(m1)
-#' mediation(m2, centrality = "mean", ci = .95)
-#' mediation(m3, centrality = "mean", ci = .95)
+#' mediation(m2, centrality = "mean", ci = 0.95)
+#' mediation(m3, centrality = "mean", ci = 0.95)
 #' }
 #' @export
 mediation <- function(model, ...) {
@@ -173,14 +172,13 @@ mediation.stanmvreg <- function(model, treatment, mediator, response = NULL, cen
                        method = "ETI",
                        pattern = "b_%s_%s",
                        ...) {
-
   # only one HDI interval
   if (length(ci) > 1) ci <- ci[1]
 
   # check for binary response. In this case, user should rescale variables
   modelinfo <- insight::model_info(model)
   if (any(sapply(modelinfo, function(i) i$is_binomial, simplify = TRUE))) {
-    message("One of moderator or outcome is binary, so direct and indirect effects may be on different scales. Consider rescaling model predictors, e.g. with `effectsize::standardize()`.")
+    insight::format_alert("One of moderator or outcome is binary, so direct and indirect effects may be on different scales. Consider rescaling model predictors, e.g. with `effectsize::standardize()`.")
   }
 
   # model responses
@@ -338,7 +336,7 @@ print.bayestestR_mediation <- function(x, digits = 3, ...) {
   x <- x[-nrow(x), ]
 
   x$CI <- insight::format_ci(x$CI_low, x$CI_high, ci = NULL, digits = digits, width = "auto", missing = "NA")
-  x <- .remove_column(x, c("CI_low", "CI_high"))
+  x <- datawizard::data_remove(x, c("CI_low", "CI_high"), verbose = FALSE)
   colnames(x)[ncol(x)] <- sprintf("%.5g%% %s", 100 * attributes(x)$ci, attributes(x)$ci_method)
 
   # remove class, to avoid conflicts with "as.data.frame.bayestestR_mediation()"
@@ -346,7 +344,7 @@ print.bayestestR_mediation <- function(x, digits = 3, ...) {
   cat(insight::export_table(x, digits = digits))
   cat("\n")
 
-  prop_mediated[] <- lapply(prop_mediated, function(i) insight::format_value(i, as_percent = TRUE))
+  prop_mediated[] <- lapply(prop_mediated, insight::format_value, as_percent = TRUE)
   insight::print_color(
     sprintf(
       "Proportion mediated: %s [%s, %s]\n",
@@ -356,7 +354,7 @@ print.bayestestR_mediation <- function(x, digits = 3, ...) {
   )
 
   if (any(prop_mediated_ori$Estimate < 0)) {
-    message("\nDirect and indirect effects have opposite directions. The proportion mediated is not meaningful.")
+    insight::format_alert("\nDirect and indirect effects have opposite directions. The proportion mediated is not meaningful.")
   }
 }
 
