@@ -1,11 +1,3 @@
-# Reexports models ------------------------
-
-#' @importFrom insight print_md
-#' @export
-insight::print_md
-
-
-#' @importFrom insight export_table
 #' @export
 print_md.describe_posterior <- function(x, digits = 2, caption = "Summary of Posterior Distribution", ...) {
   .print_md_default(x = x, digits = digits, caption = caption, ...)
@@ -128,7 +120,6 @@ print_md.bayesfactor_restricted <- function(x,
 
 #' @export
 print_md.bayesfactor_parameters <- function(x, digits = 3, log = FALSE, ...) {
-
   # retrieve information with cleaned parameter names
   cp <- attr(x, "clean_parameters")
 
@@ -153,7 +144,6 @@ print_md.bayesfactor_parameters <- function(x, digits = 3, log = FALSE, ...) {
 
 
 .print_md_default <- function(x, digits = 2, caption = NULL, subtitles = NULL, ci_string = "CI", ...) {
-
   # retrieve information with cleaned parameter names
   cp <- attr(x, "clean_parameters")
 
