@@ -1,40 +1,40 @@
 #' Sensitivity to Prior
 #'
-#' Computes the sensitivity to priors specification. This represents the proportion of change in some indices when the model is fitted with an antagonistic prior (a prior of same shape located on the opposite of the effect).
+#' Computes the sensitivity to priors specification. This represents the
+#' proportion of change in some indices when the model is fitted with an
+#' antagonistic prior (a prior of same shape located on the opposite of the
+#' effect).
 #'
 #' @param model A Bayesian model (`stanreg` or `brmsfit`).
-#' @param index The indices from which to compute the sensitivity. Can be one or multiple names of the columns returned by `describe_posterior`. The case is important here (e.g., write 'Median' instead of 'median').
-#' @param magnitude This represent the magnitude by which to shift the antagonistic prior (to test the sensitivity). For instance, a magnitude of 10 (default) means that the mode wil be updated with a prior located at 10 standard deviations from its original location.
+#' @param index The indices from which to compute the sensitivity. Can be one or
+#'   multiple names of the columns returned by `describe_posterior`. The case is
+#'   important here (e.g., write 'Median' instead of 'median').
+#' @param magnitude This represent the magnitude by which to shift the
+#'   antagonistic prior (to test the sensitivity). For instance, a magnitude of
+#'   10 (default) means that the mode wil be updated with a prior located at 10
+#'   standard deviations from its original location.
 #' @param ... Arguments passed to or from other methods.
 #'
-#' @examples
-#' \dontrun{
+#' @examplesIf require("rstanarm")
+#' \donttest{
 #' library(bayestestR)
 #'
 #' # rstanarm models
 #' # -----------------------------------------------
-#' if (require("rstanarm")) {
-#'   model <- rstanarm::stan_glm(mpg ~ wt, data = mtcars)
-#'   sensitivity_to_prior(model)
+#' model <- rstanarm::stan_glm(mpg ~ wt, data = mtcars)
+#' sensitivity_to_prior(model)
 #'
-#'   model <- rstanarm::stan_glm(mpg ~ wt + cyl, data = mtcars)
-#'   sensitivity_to_prior(model, index = c("Median", "MAP"))
-#' }
-#'
-#' # brms models
-#' # -----------------------------------------------
-#' if (require("brms")) {
-#'   model <- brms::brm(mpg ~ wt + cyl, data = mtcars)
-#'   # sensitivity_to_prior(model)
-#' }
+#' model <- rstanarm::stan_glm(mpg ~ wt + cyl, data = mtcars)
+#' sensitivity_to_prior(model, index = c("Median", "MAP"))
 #' }
 #' @seealso DescTools
 #' @export
-sensitivity_to_prior <- function(model, index = "Median", magnitude = 10, ...) {
+sensitivity_to_prior <- function(model, ...) {
   UseMethod("sensitivity_to_prior")
 }
 
 
+#' @rdname sensitivity_to_prior
 #' @export
 sensitivity_to_prior.stanreg <- function(model, index = "Median", magnitude = 10, ...) {
   # Original
@@ -60,26 +60,27 @@ sensitivity_to_prior.stanreg <- function(model, index = "Median", magnitude = 10
 }
 
 
-
-
-
-
-
-
-
-
-
-
+#' @export
+sensitivity_to_prior.default <- function(model, ...) {
+  insight::format_error(sprintf("Models of class '%s' are not yet supported.", class(model)[1]))
+}
 
 
 #' @keywords internal
 .extract_parameters <- function(model, index = "Median", ...) {
   # Handle BF
   test <- c("pd", "rope", "p_map")
-  if (any(c("bf", "bayesfactor", "bayes_factor") %in% c(index))) {
+  if (any(c("bf", "bayesfactor", "bayes_factor") %in% index)) {
     test <- c(test, "bf")
   }
-  params <- suppressMessages(describe_posterior(model, centrality = "all", dispersion = TRUE, test = test, ...))
+
+  params <- suppressMessages(describe_posterior(
+    model,
+    centrality = "all",
+    dispersion = TRUE,
+    test = test,
+    ...
+  ))
 
   params <- params[params$Parameter != "(Intercept)", ]
   params[unique(c("Parameter", "Median", index))]
