@@ -5,9 +5,9 @@
 #' updating factor greater or equal than *k*. From the perspective of the Savage-Dickey Bayes factor, testing
 #' against a point null hypothesis for any value within the support interval will yield a Bayes factor smaller
 #' than *1/k*.
-#' \cr \cr
-#' \strong{For more info, in particular on specifying correct priors for factors with more than 2 levels,
-#' see [the Bayes factors vignette](https://easystats.github.io/bayestestR/articles/bayes_factors.html).}
+#'
+#' **For more info, in particular on specifying correct priors for factors with more than 2 levels,
+#' see [the Bayes factors vignette](https://easystats.github.io/bayestestR/articles/bayes_factors.html).**
 #'
 #' @param BF The amount of support required to be included in the support interval.
 #' @inheritParams bayesfactor_parameters
@@ -20,16 +20,17 @@
 #' they should be *not flat*, and it is preferable that they be *informative* - note
 #' that by default, `brms::brm()` uses flat priors for fixed-effects; see example below).
 #'
-#' \subsection{Choosing a value of `BF`}{
-#' The choice of `BF` (the level of support) depends on what we want our interval to represent:
-#' \itemize{
-#'   \item A `BF` = 1 contains values whose credibility is not decreased by observing the data.
-#'   \item A `BF` > 1 contains values who received more impressive support from the data.
-#'   \item A `BF` < 1 contains values whose credibility has *not* been impressively decreased by observing the data.
-#'   Testing against values outside this interval will produce a Bayes factor larger than 1/`BF` in support of
-#'   the alternative. E.g., if an SI (BF = 1/3) excludes 0, the Bayes factor against the point-null will be larger than 3.
-#' }
-#' }
+#' @section Choosing a value of `BF`:
+#' The choice of `BF` (the level of support) depends on what we want our interval
+#' to represent:
+#'
+#' - A `BF` = 1 contains values whose credibility is not decreased by observing the data.
+#' - A `BF` > 1 contains values who received more impressive support from the data.
+#' - A `BF` < 1 contains values whose credibility has *not* been impressively
+#'   decreased by observing the data. Testing against values outside this interval
+#'   will produce a Bayes factor larger than 1/`BF` in support of the alternative.
+#'   E.g., if an SI (BF = 1/3) excludes 0, the Bayes factor against the point-null
+#'   will be larger than 3.
 #'
 #' @inheritSection bayesfactor_parameters Setting the correct `prior`
 #'
@@ -37,51 +38,53 @@
 #'
 #' @return
 #' A data frame containing the lower and upper bounds of the SI.
-#' \cr
+#'
 #' Note that if the level of requested support is higher than observed in the data, the
 #' interval will be `[NA,NA]`.
 #'
-#' @examples
+#' @examplesIf require("logspline") && require("rstanarm") && require("brms") && require("emmeans")
 #' library(bayestestR)
 #'
 #' prior <- distribution_normal(1000, mean = 0, sd = 1)
-#' posterior <- distribution_normal(1000, mean = .5, sd = .3)
+#' posterior <- distribution_normal(1000, mean = 0.5, sd = 0.3)
 #'
-#' si(posterior, prior)
-#' \dontrun{
+#' si(posterior, prior, verbose = FALSE)
+#' \donttest{
 #' # rstanarm models
 #' # ---------------
 #' library(rstanarm)
-#' contrasts(sleep$group) <- contr.orthonorm # see vingette
+#' contrasts(sleep$group) <- contr.equalprior_pairs # see vignette
 #' stan_model <- stan_lmer(extra ~ group + (1 | ID), data = sleep)
-#' si(stan_model)
-#' si(stan_model, BF = 3)
+#' si(stan_model, verbose = FALSE)
+#' si(stan_model, BF = 3, verbose = FALSE)
 #'
 #' # emmGrid objects
 #' # ---------------
 #' library(emmeans)
 #' group_diff <- pairs(emmeans(stan_model, ~group))
-#' si(group_diff, prior = stan_model)
+#' si(group_diff, prior = stan_model, verbose = FALSE)
 #'
 #' # brms models
 #' # -----------
 #' library(brms)
-#' contrasts(sleep$group) <- contr.orthonorm # see vingette
+#' contrasts(sleep$group) <- contr.equalprior_pairs # see vingette
 #' my_custom_priors <-
 #'   set_prior("student_t(3, 0, 1)", class = "b") +
 #'   set_prior("student_t(3, 0, 1)", class = "sd", group = "ID")
 #'
-#' brms_model <- brm(extra ~ group + (1 | ID),
+#' brms_model <- suppressWarnings(brm(extra ~ group + (1 | ID),
 #'   data = sleep,
-#'   prior = my_custom_priors
-#' )
-#' si(brms_model)
+#'   prior = my_custom_priors,
+#'   refresh = 0
+#' ))
+#' si(brms_model, verbose = FALSE)
 #' }
 #' @references
-#' Wagenmakers, E., Gronau, Q. F., Dablander, F., & Etz, A. (2018, November 22). The Support Interval. \doi{10.31234/osf.io/zwnxb}
+#' Wagenmakers, E., Gronau, Q. F., Dablander, F., & Etz, A. (2018, November 22).
+#' The Support Interval. \doi{10.31234/osf.io/zwnxb}
 #'
 #' @export
-si <- function(posterior, prior = NULL, BF = 1, verbose = TRUE, ...) {
+si <- function(posterior, ...) {
   UseMethod("si")
 }
 
@@ -91,11 +94,11 @@ si.numeric <- function(posterior, prior = NULL, BF = 1, verbose = TRUE, ...) {
   if (is.null(prior)) {
     prior <- posterior
     if (verbose) {
-      warning(insight::format_message(
+      insight::format_warning(
         "Prior not specified!",
         "Support intervals ('si') can only be computed for Bayesian models with proper priors.",
         "Please specify priors (with column order matching 'posterior')."
-      ), call. = FALSE)
+      )
     }
   }
   prior <- data.frame(X = prior)
@@ -115,7 +118,7 @@ si.numeric <- function(posterior, prior = NULL, BF = 1, verbose = TRUE, ...) {
 si.stanreg <- function(posterior, prior = NULL,
                        BF = 1, verbose = TRUE,
                        effects = c("fixed", "random", "all"),
-                       component = c("conditional", "location", "zi", "zero_inflated", "all", "smooth_terms", "sigma", "distributional", "auxiliary"),
+                       component = c("location", "conditional", "all", "smooth_terms", "sigma", "auxiliary", "distributional"),
                        parameters = NULL,
                        ...) {
   cleaned_parameters <- insight::clean_parameters(posterior)
@@ -123,9 +126,8 @@ si.stanreg <- function(posterior, prior = NULL,
   component <- match.arg(component)
 
   samps <- .clean_priors_and_posteriors(posterior, prior,
-    verbose = verbose,
     effects = effects, component = component,
-    parameters = parameters
+    parameters = parameters, verbose = verbose
   )
 
   # Get SIs
@@ -137,7 +139,7 @@ si.stanreg <- function(posterior, prior = NULL,
   out <- .prepare_output(temp, cleaned_parameters, inherits(posterior, "stanmvreg"))
 
   attr(out, "ci_method") <- "SI"
-  attr(out, "object_name") <- insight::safe_deparse(substitute(posterior))
+  attr(out, "object_name") <- insight::safe_deparse_symbol(substitute(posterior))
   class(out) <- class(temp)
   attr(out, "plot_data") <- attr(temp, "plot_data")
 
@@ -169,7 +171,7 @@ si.emmGrid <- function(posterior, prior = NULL,
   )
 
   attr(out, "ci_method") <- "SI"
-  attr(out, "object_name") <- insight::safe_deparse(substitute(posterior))
+  attr(out, "object_name") <- insight::safe_deparse_symbol(substitute(posterior))
   out
 }
 
@@ -182,14 +184,30 @@ si.stanfit <- function(posterior, prior = NULL, BF = 1, verbose = TRUE, effects
   out <- si(insight::get_parameters(posterior, effects = effects),
     prior = prior, BF = BF, verbose = verbose
   )
-  attr(out, "object_name") <- insight::safe_deparse(substitute(posterior))
+  attr(out, "object_name") <- insight::safe_deparse_symbol(substitute(posterior))
   out
 }
 
+
+#' @rdname si
 #' @export
-si.get_predicted <- function(posterior, ...) {
-  out <- si(as.data.frame(t(posterior)), ...)
-  attr(out, "object_name") <- insight::safe_deparse(substitute(posterior))
+si.get_predicted <- function(posterior, prior = NULL, BF = 1, use_iterations = FALSE, verbose = TRUE, ...) {
+  if (isTRUE(use_iterations)) {
+    if ("iterations" %in% names(attributes(posterior))) {
+      out <- si(
+        as.data.frame(t(attributes(posterior)$iterations)),
+        prior = prior,
+        BF = BF,
+        verbose = verbose,
+        ...
+      )
+    } else {
+      insight::format_error("No iterations present in the output.")
+    }
+    attr(out, "object_name") <- insight::safe_deparse_symbol(substitute(posterior))
+  } else {
+    out <- si(insight::get_parameters(posterior), prior = prior, BF = BF, verbose = verbose, ...)
+  }
   out
 }
 
@@ -199,23 +217,22 @@ si.get_predicted <- function(posterior, ...) {
 si.data.frame <- function(posterior, prior = NULL, BF = 1, verbose = TRUE, ...) {
   if (is.null(prior)) {
     prior <- posterior
-    warning(insight::format_message(
+    insight::format_warning(
       "Prior not specified!",
       "Support intervals ('si') can only be computed for Bayesian models with proper priors.",
       "Please specify priors (with column order matching 'posterior')."
-    ), call. = FALSE)
+    )
   }
 
   if (verbose && (nrow(posterior) < 4e4 || nrow(prior) < 4e4)) {
-    warning(
-      "Support intervals might not be precise.\n",
-      "For precise support intervals, sampling at least 40,000 posterior samples is recommended.",
-      call. = FALSE
+    insight::format_warning(
+      "Support intervals might not be precise.",
+      "For precise support intervals, sampling at least 40,000 posterior samples is recommended."
     )
   }
 
   out <- lapply(BF, function(BFi) {
-    .si.data.frame(posterior, prior, BFi)
+    .si.data.frame(posterior, prior, BFi, verbose = verbose)
   })
   out <- do.call(rbind, out)
 
@@ -233,16 +250,21 @@ si.draws <- function(posterior, prior = NULL, BF = 1, verbose = TRUE, ...) {
   si(.posterior_draws_to_df(posterior), prior = prior, BF = BF, verbose = verbose, ...)
 }
 
+#' @export
+si.rvar <- si.draws
+
 
 
 # Helper ------------------------------------------------------------------
 
-.si.data.frame <- function(posterior, prior, BF, ...) {
+.si.data.frame <- function(posterior, prior, BF, verbose = TRUE, ...) {
   sis <- matrix(NA, nrow = ncol(posterior), ncol = 2)
   for (par in seq_along(posterior)) {
     sis[par, ] <- .si(posterior[[par]],
       prior[[par]],
-      BF = BF, ...
+      BF = BF,
+      verbose = verbose,
+      ...
     )
   }
 
@@ -258,7 +280,7 @@ si.draws <- function(posterior, prior = NULL, BF = 1, verbose = TRUE, ...) {
 
 
 #' @keywords internal
-.si <- function(posterior, prior, BF = 1, extend_scale = 0.05, precision = 2^8, ...) {
+.si <- function(posterior, prior, BF = 1, extend_scale = 0.05, precision = 2^8, verbose = TRUE, ...) {
   insight::check_if_installed("logspline")
 
   if (isTRUE(all.equal(prior, posterior))) {
@@ -287,15 +309,15 @@ si.draws <- function(posterior, prior = NULL, BF = 1, verbose = TRUE, ...) {
 
   crit <- relative_d >= BF
 
-  cp <- rle(c(stats::na.omit(crit)))
-  if (length(cp$lengths) > 3) {
-    warning("More than 1 SI detected. Plot the result to investigate.", call. = FALSE)
+  cp <- rle(stats::na.omit(crit))
+  if (length(cp$lengths) > 3 && verbose) {
+    insight::format_warning("More than 1 SI detected. Plot the result to investigate.")
   }
 
   x_supported <- stats::na.omit(x_axis[crit])
   if (length(x_supported) < 2) {
     return(c(NA, NA))
-  } else {
-    range(x_supported)
   }
+
+  range(x_supported)
 }
