@@ -3,8 +3,10 @@
 #' Simulate data with specific characteristics.
 #'
 #' @param n The number of observations to be generated.
-#' @param r A value or vector corresponding to the desired correlation coefficients.
-#' @param d A value or vector corresponding to the desired difference between the groups.
+#' @param r A value or vector corresponding to the desired correlation
+#'   coefficients.
+#' @param d A value or vector corresponding to the desired difference between
+#'   the groups.
 #' @param mean A value or vector corresponding to the mean of the variables.
 #' @param sd A value or vector corresponding to the SD of the variables.
 #' @param names A character vector of desired variable names.
@@ -25,12 +27,13 @@
 #' summary(lm(V2 ~ V1, data = data))
 #'
 #' # Generate multiple variables
-#' cor_matrix <- matrix(c(
-#'   1.0, 0.2, 0.4,
-#'   0.2, 1.0, 0.3,
-#'   0.4, 0.3, 1.0
-#' ),
-#' nrow = 3
+#' cor_matrix <- matrix(
+#'   c(
+#'     1.0, 0.2, 0.4,
+#'     0.2, 1.0, 0.3,
+#'     0.4, 0.3, 1.0
+#'   ),
+#'   nrow = 3
 #' )
 #'
 #' data <- simulate_correlation(r = cor_matrix, names = c("y", "x1", "x2"))
@@ -53,30 +56,33 @@
 #' summary(lm(V1 ~ V0, data = data))
 #' summary(glm(V0 ~ V1, data = data, family = "binomial"))
 #' @export
-simulate_correlation <- function(n = 100, r = 0.5, mean = 0, sd = 1, names = NULL, ...) {
-  if (!requireNamespace("MASS", quietly = TRUE)) {
-    stop("Package 'MASS' required for this function to work. Please install it by running `install.packages('MASS')`.")
-  }
+simulate_correlation <- function(n = 100,
+                                 r = 0.5,
+                                 mean = 0,
+                                 sd = 1,
+                                 names = NULL,
+                                 ...) {
+  insight::check_if_installed("MASS")
 
   # Define matrix
   if (is.matrix(r)) {
     if (isSymmetric(r)) {
       if (any(r > 1)) {
-        stop("'r' should only contain values between -1 and 1.")
+        insight::format_error("`r` should only contain values between -1 and 1.")
       } else {
         sigma <- r
       }
     } else {
-      stop("'r' should be a symetric matrix (relative to the diagonal).")
+      insight::format_error("`r` should be a symetric matrix (relative to the diagonal).")
     }
-  } else if (length(r) == 1) {
+  } else if (length(r) == 1L) {
     if (abs(r) > 1) {
-      stop("'r' should only contain values between -1 and 1.")
+      insight::format_error("`r` should only contain values between -1 and 1.")
     } else {
       sigma <- matrix(c(1, r, r, 1), nrow = 2)
     }
   } else {
-    stop("'r' should be a value (e.g., r = 0.5) or a square matrix.")
+    insight::format_error("`r` should be a value (e.g., r = 0.5) or a square matrix.")
   }
 
 
@@ -101,10 +107,8 @@ simulate_correlation <- function(n = 100, r = 0.5, mean = 0, sd = 1, names = NUL
   data <- as.data.frame(data)
 
   # Rename
-  if (!is.null(names)) {
-    if (length(names) == ncol(data)) {
-      names(data) <- names
-    }
+  if (!is.null(names) && length(names) == ncol(data)) {
+    names(data) <- names
   }
   data
 }
@@ -122,10 +126,8 @@ simulate_ttest <- function(n = 100, d = 0.5, names = NULL, ...) {
   data <- data.frame(y = as.factor(y), x = x)
   names(data) <- paste0("V", 0:(ncol(data) - 1))
 
-  if (!is.null(names)) {
-    if (length(names) == ncol(data)) {
-      names(data) <- names
-    }
+  if (!is.null(names) && length(names) == ncol(data)) {
+    names(data) <- names
   }
   data
 }
@@ -143,10 +145,8 @@ simulate_difference <- function(n = 100, d = 0.5, names = NULL, ...) {
   )
   names(data) <- paste0("V", 0:(ncol(data) - 1))
 
-  if (!is.null(names)) {
-    if (length(names) == ncol(data)) {
-      names(data) <- names
-    }
+  if (!is.null(names) && length(names) == ncol(data)) {
+    names(data) <- names
   }
   data
 }
