@@ -1,79 +1,14 @@
-# trim leading / trailing whitespace
-.trim <- function(x) gsub("^\\s+|\\s+$", "", x)
-
-
-# safe depare, also for very long strings
-.safe_deparse <- function(string) {
-  paste0(sapply(deparse(string, width.cutoff = 500), .trim, simplify = TRUE), collapse = "")
+# small wrapper around this commonly used try-catch
+.safe <- function(code, on_error = NULL) {
+  tryCatch(code, error = function(e) on_error)
 }
 
-
-# has object an element with given name?
-#' @keywords internal
-.obj_has_name <- function(x, name) {
-  name %in% names(x)
-}
-
-# remove NULL elements from lists
-#' @keywords internal
-.compact_list <- function(x) x[!sapply(x, function(i) length(i) == 0 || is.null(i) || any(i == "NULL", na.rm = TRUE))]
-
-# is string empty?
-#' @keywords internal
-.is_empty_object <- function(x) {
-  if (is.list(x)) {
-    x <- tryCatch(
-      {
-        .compact_list(x)
-      },
-      error = function(x) {
-        x
-      }
-    )
-  }
-  # this is an ugly fix because of ugly tibbles
-  if (inherits(x, c("tbl_df", "tbl"))) x <- as.data.frame(x)
-  x <- suppressWarnings(x[!is.na(x)])
-  length(x) == 0 || is.null(x)
-}
-
-
 # select rows where values in "variable" match "value"
 #' @keywords internal
 .select_rows <- function(data, variable, value) {
   data[which(data[[variable]] == value), ]
 }
 
-# remove column
-#' @keywords internal
-.remove_column <- function(data, variables) {
-  data[variables] <- NULL
-  data
-}
-
-
-#' @importFrom stats reshape
-#' @keywords internal
-.to_long <- function(x, names_to = "key", values_to = "value", columns = colnames(x)) {
-  if (is.numeric(columns)) columns <- colnames(x)[columns]
-  dat <- stats::reshape(
-    as.data.frame(x),
-    idvar = "id",
-    ids = row.names(x),
-    times = columns,
-    timevar = names_to,
-    v.names = values_to,
-    varying = list(columns),
-    direction = "long"
-  )
-
-  if (is.factor(dat[[values_to]])) {
-    dat[[values_to]] <- as.character(dat[[values_to]])
-  }
-
-  dat[, 1:(ncol(dat) - 1), drop = FALSE]
-}
-
 #' select numerics columns
 #' @keywords internal
 .select_nums <- function(x) {
@@ -81,33 +16,11 @@
 }
 
 
-
-## TODO remove?!?
-
-# #' Used in describe_posterior
-# #' @keywords internal
-# .reorder_rows <- function(x, out, ci = NULL) {
-#   if (!is.data.frame(out) || nrow(out) == 1) {
-#     return(out)
-#   }
-#
-#   if (is.null(ci)) {
-#     refdata <- point_estimate(x, centrality = "median", dispersion = FALSE)
-#     order <- refdata$Parameter
-#     out <- out[match(order, out$Parameter), ]
-#   } else {
-#     uncertainty <- ci(x, ci = ci)
-#     order <- paste0(uncertainty$Parameter, uncertainty$CI)
-#     out <- out[match(order, paste0(out$Parameter, out$CI)), ]
-#   }
-#   rownames(out) <- NULL
-#   out
-# }
-
-
 #' @keywords internal
 .get_direction <- function(direction) {
-  if (length(direction) > 1) warning("Using first 'direction' value.")
+  if (length(direction) > 1) {
+    insight::format_warning("Using first 'direction' value.")
+  }
 
   if (is.numeric(direction[1])) {
     return(sign(direction[1]))
@@ -133,37 +46,53 @@
   direction <- Value[tolower(direction[1])]
 
   if (is.na(direction)) {
-    stop("Unrecognized 'direction' argument.")
+    insight::format_error("Unrecognized 'direction' argument.")
   }
   direction
 }
 
 
 #' @keywords internal
-.prepare_output <- function(temp, cleaned_parameters, is_stan_mv = FALSE, is_brms_mv = FALSE) {
+.prepare_output <- function(temp,
+                            cleaned_parameters,
+                            is_stan_mv = FALSE,
+                            is_brms_mv = FALSE) {
+  if (is.null(cleaned_parameters)) {
+    return(temp)
+  }
   if (isTRUE(is_stan_mv)) {
+    # for models with multiple responses, we create a separate response column
     temp$Response <- gsub("(b\\[)*(.*)\\|(.*)", "\\2", temp$Parameter)
+    # from the parameter names, we can now remove the name of the respone variables
     for (i in unique(temp$Response)) {
       temp$Parameter <- gsub(sprintf("%s|", i), "", temp$Parameter, fixed = TRUE)
     }
     merge_by <- c("Parameter", "Effects", "Component", "Response")
     remove_cols <- c("Group", "Cleaned_Parameter", "Function", ".roworder")
   } else if (isTRUE(is_brms_mv)) {
+    # for models with multiple responses, we create a separate response column
     temp$Response <- gsub("(.*)_(.*)_(.*)", "\\2", temp$Parameter)
-    # temp$Parameter <- gsub("(.*)_(.*)_(.*)", "\\1_\\3", temp$Parameter)
     merge_by <- c("Parameter", "Effects", "Component", "Response")
     remove_cols <- c("Group", "Cleaned_Parameter", "Function", ".roworder")
   } else {
+    # By default, we only merge by these three columns
     merge_by <- c("Parameter", "Effects", "Component")
     remove_cols <- c("Group", "Cleaned_Parameter", "Response", "Function", ".roworder")
   }
+
+  # in "temp", we have the data frame from the related functions (like
+  # `point_estimate()`, `ci()`  etc.). "cleaned_parameters" is a data frame
+  # only with original parameter names, model components and "cleaned"
+  # parameter names (retrieved from `insight::clean_parameters()`).
+
   merge_by <- intersect(merge_by, colnames(temp))
-  temp$.roworder <- 1:nrow(temp)
+  temp$.roworder <- seq_len(nrow(temp))
   out <- merge(x = temp, y = cleaned_parameters, by = merge_by, all.x = TRUE)
+
   # hope this works for stanmvreg...
   if ((isTRUE(is_stan_mv) || isTRUE(is_brms_mv)) && all(is.na(out$Effects)) && all(is.na(out$Component))) {
-    out$Effects <- cleaned_parameters$Effects[1:nrow(out)]
-    out$Component <- cleaned_parameters$Component[1:nrow(out)]
+    out$Effects <- cleaned_parameters$Effects[seq_len(nrow(out))]
+    out$Component <- cleaned_parameters$Component[seq_len(nrow(out))]
   }
   # this here is required for multiple response models...
   if (all(is.na(out$Effects)) || all(is.na(out$Component))) {
@@ -172,7 +101,7 @@
     out <- out[!is.na(out$Effects) & !is.na(out$Component) & !duplicated(out$.roworder), ]
   }
   attr(out, "Cleaned_Parameter") <- out$Cleaned_Parameter[order(out$.roworder)]
-  .remove_column(out[order(out$.roworder), ], remove_cols)
+  datawizard::data_remove(out[order(out$.roworder), ], remove_cols, verbose = FALSE)
 }
 
 
@@ -181,29 +110,12 @@
   if (is.null(ncol(y))) {
     return(x)
   }
-  x$.rowid <- 1:nrow(x)
+  x$.rowid <- seq_len(nrow(x))
   x <- merge(x, y, by = by, all = all)
-  .remove_column(x[order(x$.rowid), ], ".rowid")
+  datawizard::data_remove(x[order(x$.rowid), ], ".rowid", verbose = FALSE)
 }
 
 
-
-# returns the row-indices for grouped data frames
-#' @keywords internal
-.group_indices <- function(x) {
-  # dplyr < 0.8.0 returns attribute "indices"
-  grps <- attr(x, "groups", exact = TRUE)
-
-  # dplyr < 0.8.0?
-  if (is.null(grps)) {
-    attr(x, "indices", exact = TRUE)
-  } else {
-    grps[[".rows"]]
-  }
-}
-
-
-
 # returns the variables that were used for grouping data frames (dplyr::group_var())
 #' @keywords internal
 .group_vars <- function(x) {
@@ -242,13 +154,3 @@
   attr(params, "clean_parameters") <- cp
   params
 }
-
-
-#' @importFrom stats na.omit
-.n_unique <- function(x, na.rm = TRUE) {
-  if (is.null(x)) {
-    return(0)
-  }
-  if (isTRUE(na.rm)) x <- stats::na.omit(x)
-  length(unique(x))
-}
