@@ -1,16 +1,14 @@
-
 # clean priors and posteriors ---------------------------------------------
 
 #' @keywords internal
-.clean_priors_and_posteriors <- function(posterior, prior,
-                                         verbose = TRUE, ...) {
+.clean_priors_and_posteriors <- function(posterior, prior, ...) {
   UseMethod(".clean_priors_and_posteriors")
 }
 
 #' @keywords internal
 .clean_priors_and_posteriors.stanreg <- function(posterior, prior,
                                                  verbose = TRUE,
-                                                 effects, component, ...) {
+                                                 ...) {
   # Get Priors
   if (is.null(prior)) {
     prior <- posterior
@@ -19,7 +17,7 @@
 
   prior <- try(unupdate(prior, verbose = verbose), silent = TRUE)
   if (methods::is(prior, "try-error")) {
-    if (grepl("flat priors", prior)) {
+    if (grepl("flat priors", prior, fixed = TRUE)) {
       prior <- paste0(
         prior, "Could not therefore compute Bayes factors, as these inform about ",
         "the raltive likelihood of two 'hypotheses', and flat priors provide no ",
@@ -27,11 +25,11 @@
         "See '?bayesfactor_parameters' for more information.\n"
       )
     }
-    stop(prior, call. = FALSE)
+    insight::format_error(prior)
   }
 
-  prior <- insight::get_parameters(prior, effects = effects, component = component, ...)
-  posterior <- insight::get_parameters(posterior, effects = effects, component = component, ...)
+  prior <- insight::get_parameters(prior, ...)
+  posterior <- insight::get_parameters(posterior, ...)
 
   list(
     posterior = posterior,
@@ -66,41 +64,38 @@
 #' @keywords internal
 .clean_priors_and_posteriors.emmGrid <- function(posterior,
                                                  prior,
-                                                 verbose = TRUE) {
+                                                 verbose = TRUE,
+                                                 ...) {
   insight::check_if_installed("emmeans")
 
   if (is.null(prior)) {
     prior <- posterior
-    warning(
-      "Prior not specified! ",
-      "Please provide the original model to get meaningful results."
-    )
+    insight::format_warning("Prior not specified! Please provide the original model to get meaningful results.")
   }
 
 
   if (!inherits(prior, "emmGrid")) {
     # then is it a model
     on.exit(
-      stop(
+      insight::format_error(paste0(
         "Unable to reconstruct prior estimates.\n",
         "Perhaps the emmGrid object has been transformed or regrid()-ed?\n",
         "See function details.\n\n",
         "Instead, you can reestimate the emmGrid with a prior model, Try:\n",
         "\tprior_model <- unupdate(mode)\n",
-        "\tprior_emmgrid <- emmeans(prior_model, ...) # pass this as the 'prior' argument.",
-        call. = FALSE
-      )
+        "\tprior_emmgrid <- emmeans(prior_model, ...) # pass this as the 'prior' argument."
+      ))
     )
 
     if (inherits(prior, "brmsfit")) {
-      stop("Cannot rebuild prior emmGrid from a brmsfit model.", call. = FALSE)
+      insight::format_error("Cannot rebuild prior emmGrid from a brmsfit model.")
     }
 
 
     prior <- try(unupdate(prior, verbose = verbose), silent = TRUE)
     if (inherits(prior, "try-error")) {
       on.exit() # undo general error message
-      if (grepl("flat priors", prior)) {
+      if (grepl("flat priors", prior, fixed = TRUE)) {
         prior <- paste0(
           prior, "Could not therefore compute Bayes factors, as these inform about ",
           "the raltive likelihood of two 'hypotheses', and flat priors provide no ",
@@ -108,16 +103,14 @@
           "See '?bayesfactor_parameters' for more information.\n"
         )
       }
-      stop(prior, call. = FALSE)
+      insight::format_error(prior)
     }
 
-    prior <- emmeans::ref_grid(prior)
+    prior <- suppressWarnings(emmeans::ref_grid(prior))
     prior <- prior@post.beta
 
     if (!isTRUE(all.equal(colnames(prior), colnames(posterior@post.beta)))) {
-      stop("post.beta and prior.beta are non-conformable arguments.",
-        call. = FALSE
-      )
+      insight::format_error("post.beta and prior.beta are non-conformable arguments.")
     }
     prior <- stats::update(posterior, post.beta = prior)
     on.exit() # undo general error message
@@ -133,25 +126,22 @@
 }
 
 .clean_priors_and_posteriors.emm_list <- function(posterior, prior,
-                                                  verbose = TRUE) {
+                                                  verbose = TRUE, ...) {
   if (is.null(prior)) {
     prior <- posterior
-    warning(
-      "Prior not specified! ",
-      "Please provide the original model to get meaningful results."
-    )
+    insight::format_warning("Prior not specified! Please provide the original model to get meaningful results.")
   }
 
   if (!inherits(prior, "emm_list")) {
     # prior is a model
 
     if (inherits(prior, "brmsfit")) {
-      stop("Cannot rebuild prior emm_list from a brmsfit model.", call. = FALSE)
+      insight::format_error("Cannot rebuild prior emm_list from a brmsfit model.")
     }
 
     prior <- try(unupdate(prior, verbose = verbose), silent = TRUE)
     if (inherits(prior, "try-error")) {
-      if (grepl("flat priors", prior)) {
+      if (grepl("flat priors", prior, fixed = TRUE)) {
         prior <- paste0(
           prior, "Could not therefore compute Bayes factors, as these inform about ",
           "the raltive likelihood of two 'hypotheses', and flat priors provide no ",
@@ -159,7 +149,7 @@
           "See '?bayesfactor_parameters' for more information.\n"
         )
       }
-      stop(prior, call. = FALSE)
+      insight::format_error(prior)
     }
   }
   # prior is now a model, or emm_list
@@ -200,11 +190,10 @@
 
   # Prior and post odds
   Modelnames <- BFGrid$Model
-  if (!is.null(priorOdds)) {
-    priorOdds <- c(1, priorOdds)
-  } else {
-    priorOdds <- rep(1, length(Modelnames))
+  if (is.null(priorOdds)) {
+    priorOdds <- rep(1, length(Modelnames) - 1)
   }
+  priorOdds <- c(1, priorOdds)
 
   prior_logodds <- log(priorOdds)
   posterior_logodds <- prior_logodds + BFGrid$log_BF
@@ -240,8 +229,8 @@
 #' @keywords internal
 .make_terms <- function(formula) {
   sort_interactions <- function(x) {
-    if (grepl("\\:", x)) {
-      effs <- unlist(strsplit(x, "\\:"))
+    if (grepl(":", x, fixed = TRUE)) {
+      effs <- unlist(strsplit(x, ":", fixed = TRUE))
       x <- paste0(sort(effs), collapse = ":")
     }
     x
@@ -250,13 +239,13 @@
   all.terms <- attr(stats::terms(formula.f), "term.labels")
 
   # Fixed
-  fix_trms <- all.terms[!grepl("\\|", all.terms)] # no random
+  fix_trms <- all.terms[!grepl("|", all.terms, fixed = TRUE)] # no random
   if (length(fix_trms) > 0) {
     fix_trms <- sapply(fix_trms, sort_interactions)
   }
 
   # Random
-  random_parts <- paste0(all.terms[grepl("\\|", all.terms)]) # only random
+  random_parts <- paste0(grep("|", all.terms, fixed = TRUE, value = TRUE)) # only random
   if (length(random_parts) == 0) {
     return(fix_trms)
   }
@@ -272,7 +261,7 @@
     tmp_trms <- attr(stats::terms.formula(tmp_random[[i]]), "term.labels")
     tmp_trms <- sapply(tmp_trms, sort_interactions)
 
-    if (!any(unlist(strsplit(as.character(tmp_random[[i]])[[2]], " \\+ ")) == "0")) {
+    if (!any(unlist(strsplit(as.character(tmp_random[[i]])[[2]], " + ", fixed = TRUE)) == "0")) {
       tmp_trms <- c("1", tmp_trms)
     }
 
@@ -295,7 +284,7 @@
   insight::check_if_installed("logspline")
 
   estimate_samples_density <- function(samples) {
-    nm <- insight::safe_deparse(substitute(samples))
+    nm <- insight::safe_deparse_symbol(substitute(samples))
     samples <- utils::stack(samples)
     samples <- split(samples, samples$ind)
 
@@ -357,7 +346,7 @@
     samplesX <- do.call("rbind", samplesX)
 
     samplesX$Distribution <- point0$Distribution <- nm
-    rownames(samplesX) <- rownames(point0) <- c()
+    rownames(samplesX) <- rownames(point0) <- NULL
 
     list(samplesX, point0)
   }
