@@ -22,12 +22,12 @@
 #' subtracting for continuous variables, and effects coding via `contr.sum` or
 #' orthonormal coding via [`contr.equalprior_pairs`] for factors) can reduce this
 #' issue. In any case you should be mindful of this issue.
-#' \cr\cr
+#'
 #' See [bayesfactor_models()] details for more info on passed models.
-#' \cr\cr
+#'
 #' Note that for `BayesFactor` models, posterior samples cannot be generated
 #' from intercept only models.
-#' \cr\cr
+#'
 #' This function is similar in function to `brms::posterior_average`.
 #'
 #' @note For `BayesFactor < 0.9.12-4.3`, in some instances there might be
@@ -36,27 +36,26 @@
 #'
 #' @return A data frame with posterior distributions (weighted across models) .
 #'
-#' @seealso [bayesfactor_inclusion()] for Bayesian model averaging.
+#' @seealso [`bayesfactor_inclusion()`] for Bayesian model averaging.
 #'
 #' @examples
 #' \donttest{
-#' if (require("rstanarm") && require("see")) {
-#'   stan_m0 <- stan_glm(extra ~ 1,
+#' if (require("rstanarm") && require("see") && interactive()) {
+#'   stan_m0 <- suppressWarnings(stan_glm(extra ~ 1,
 #'     data = sleep,
 #'     family = gaussian(),
 #'     refresh = 0,
 #'     diagnostic_file = file.path(tempdir(), "df0.csv")
-#'   )
+#'   ))
 #'
-#'   stan_m1 <- stan_glm(extra ~ group,
+#'   stan_m1 <- suppressWarnings(stan_glm(extra ~ group,
 #'     data = sleep,
 #'     family = gaussian(),
 #'     refresh = 0,
 #'     diagnostic_file = file.path(tempdir(), "df1.csv")
-#'   )
+#'   ))
 #'
-#'
-#'   res <- weighted_posteriors(stan_m0, stan_m1)
+#'   res <- weighted_posteriors(stan_m0, stan_m1, verbose = FALSE)
 #'
 #'   plot(eti(res))
 #' }
@@ -65,39 +64,42 @@
 #' if (require("BayesFactor")) {
 #'   extra_sleep <- ttestBF(formula = extra ~ group, data = sleep)
 #'
-#'   wp <- weighted_posteriors(extra_sleep)
+#'   wp <- weighted_posteriors(extra_sleep, verbose = FALSE)
 #'
-#'   describe_posterior(extra_sleep, test = NULL)
-#'   describe_posterior(wp$delta, test = NULL) # also considers the null
+#'   describe_posterior(extra_sleep, test = NULL, verbose = FALSE)
+#'   # also considers the null
+#'   describe_posterior(wp$delta, test = NULL, verbose = FALSE)
 #' }
 #'
 #'
 #' ## weighted prediction distributions via data.frames
-#' if (require("rstanarm")) {
-#'   m0 <- stan_glm(
+#' if (require("rstanarm") && interactive()) {
+#'   m0 <- suppressWarnings(stan_glm(
 #'     mpg ~ 1,
 #'     data = mtcars,
 #'     family = gaussian(),
 #'     diagnostic_file = file.path(tempdir(), "df0.csv"),
 #'     refresh = 0
-#'   )
+#'   ))
 #'
-#'   m1 <- stan_glm(
+#'   m1 <- suppressWarnings(stan_glm(
 #'     mpg ~ carb,
 #'     data = mtcars,
 #'     family = gaussian(),
 #'     diagnostic_file = file.path(tempdir(), "df1.csv"),
 #'     refresh = 0
-#'   )
+#'   ))
 #'
 #'   # Predictions:
 #'   pred_m0 <- data.frame(posterior_predict(m0))
 #'   pred_m1 <- data.frame(posterior_predict(m1))
 #'
-#'   BFmods <- bayesfactor_models(m0, m1)
+#'   BFmods <- bayesfactor_models(m0, m1, verbose = FALSE)
 #'
-#'   wp <- weighted_posteriors(pred_m0, pred_m1,
-#'     prior_odds = as.numeric(BFmods)[2]
+#'   wp <- weighted_posteriors(
+#'     pred_m0, pred_m1,
+#'     prior_odds = as.numeric(BFmods)[2],
+#'     verbose = FALSE
 #'   )
 #'
 #'   # look at first 5 prediction intervals
@@ -136,16 +138,18 @@ weighted_posteriors.data.frame <- function(..., prior_odds = NULL, missing = 0,
   mnames <- sapply(match.call(expand.dots = FALSE)$`...`, insight::safe_deparse)
 
   # find min nrow
-  iterations <- min(sapply(Mods, nrow))
+  iterations <- min(vapply(Mods, nrow, numeric(1)))
 
   # make weights from prior_odds
   if (!is.null(prior_odds)) {
     prior_odds <- c(1, prior_odds)
   } else {
-    warning("'prior_odds = NULL'; Using uniform priors odds.\n",
-      "For weighted data frame, 'prior_odds' should be specified as a numeric vector.",
-      call. = FALSE
-    )
+    if (verbose) {
+      insight::format_warning(
+        "'prior_odds = NULL'; Using uniform priors odds.\n",
+        "For weighted data frame, 'prior_odds' should be specified as a numeric vector."
+      )
+    }
     prior_odds <- rep(1, length(Mods))
   }
 
